.. _AUTHORS:

Contributors
============

Development
~~~~~~~~~~~

* Rikard Nordgren, rikard.nordgren@farmaci.uu.se (maintainer)
* Stella Belin, stella.belin@farmaci.uu.se (maintainer)
* Kajsa Harling
* Zhe Huang, zhe.huang@farmaci.uu.se
* Aurelien Ooms
* Gunnar Yngman, gunnar.yngman@farmaci.uu.se

Scientific input
~~~~~~~~~~~~~~~~

* Mats O. Karlsson
* Andrew C. Hooker
* João A. Abrantes
* Piyanan Assawasuwannakit
* Simon Buatois
* Simon Carter
* Xiaomei Chen
* Alzahra Hamdan
* Osama Qutishat
* Sebastian Ueckert
* Shijun Wang
* Tianwu Yang

Funding
~~~~~~~

A warm thanks to all our sponsors!

*  F\. Hoffman-La Roche Ltd.
*  Pharmetheus
*  Uppsala University

Part of the computations needed for testing of Pharmpy was enabled by resources provided by the Swedish National Infrastructure for Computing (SNIC) at UPPMAX, partially funded by the Swedish Research Council.
